@@ -1,5 +1,6 @@
-dep.t.test <- function(formula, data, block, sig.level=.05, digits=3){
-  xx <- aggregate(formula, data=data, FUN=sumfun)$y
+dep.t.test <-
+function(formula, data, block, sig.level=.05, digits=3){
+  xx <- aggregate(formula, data=data, FUN=sumfun)[[2]]
     
   indvar <- unlist(strsplit(as.character(formula), " ")[3])
   depvar <- unlist(strsplit(as.character(formula), " ")[2])
@@ -9,3 +10,4 @@ dep.t.test <- function(formula, data, block, sig.level=.05, digits=3){
   output <- dep.t.test.second(m=xx[,1], sd=xx[,2], n=xx[1,3], corr=corr, sig.level=sig.level,digits=digits)
   return(output) 
 }
+
